summaryrefslogtreecommitdiffstats
path: root/kandy/src/kandy.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kandy/src/kandy.cpp')
-rw-r--r--kandy/src/kandy.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/kandy/src/kandy.cpp b/kandy/src/kandy.cpp
index eeae6f2d..c46f9687 100644
--- a/kandy/src/kandy.cpp
+++ b/kandy/src/kandy.cpp
@@ -58,7 +58,7 @@
#include "kandy.moc"
Kandy::Kandy(CommandScheduler *scheduler)
- : KMainWindow( 0, "Kandy" ),
+ : TDEMainWindow( 0, "Kandy" ),
mPrinter(0)
{
mScheduler = scheduler;
@@ -70,7 +70,7 @@ Kandy::Kandy(CommandScheduler *scheduler)
// accept dnd
setAcceptDrops(true);
// tell the KMainWindow that this is indeed the main widget
setCentralWidget(mView);
// then, setup our actions
@@ -136,12 +136,12 @@ void Kandy::setupActions()
KStdAction::configureToolbars(TQT_TQOBJECT(this), TQT_SLOT(optionsConfigureToolbars()), actionCollection());
KStdAction::preferences(TQT_TQOBJECT(this), TQT_SLOT(optionsPreferences()), actionCollection());
- new KAction(i18n("Mobile GUI"),0,TQT_TQOBJECT(this),TQT_SLOT(showMobileGui()),
+ new TDEAction(i18n("Mobile GUI"),0,TQT_TQOBJECT(this),TQT_SLOT(showMobileGui()),
actionCollection(),"show_mobilegui");
- mConnectAction = new KAction(i18n("Connect"),0,TQT_TQOBJECT(this),TQT_SLOT(modemConnect()),
+ mConnectAction = new TDEAction(i18n("Connect"),0,TQT_TQOBJECT(this),TQT_SLOT(modemConnect()),
actionCollection(),"modem_connect");
- mDisconnectAction = new KAction(i18n("Disconnect"),0,TQT_TQOBJECT(this),
+ mDisconnectAction = new TDEAction(i18n("Disconnect"),0,TQT_TQOBJECT(this),
TQT_SLOT(modemDisconnect()),actionCollection(),
"modem_disconnect");
@@ -166,7 +166,7 @@ void Kandy::readProperties(TDEConfig */*config*/)
void Kandy::dragEnterEvent(TQDragEnterEvent *event)
{
// do nothing
- KMainWindow::dragEnterEvent(event);
+ TDEMainWindow::dragEnterEvent(event);
// accept uri drops only
// event->accept(KURLDrag::canDecode(event));
@@ -179,7 +179,7 @@ void Kandy::dropEvent(TQDropEvent *event)
// much more, so please read the docs there
// do nothing
- KMainWindow::dropEvent(event);
+ TDEMainWindow::dropEvent(event);
/*
KURL::List list;
@@ -70,7 +70,7 @@ Kandy::Kandy(CommandScheduler *scheduler)
// accept dnd
setAcceptDrops(true);
- // tell the KMainWindow that this is indeed the main widget
+ // tell the TDEMainWindow that this is indeed the main widget
setCentralWidget(mView);
// then, setup our actions